@@ -54,84 +54,84 @@
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="67"/>
+        <location filename="../appearancepage.cpp" line="65"/>
         <source>Create</source>
         <translation>Creëren</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="68"/>
+        <location filename="../appearancepage.cpp" line="66"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="69"/>
+        <location filename="../appearancepage.cpp" line="67"/>
         <source>Create a Copy</source>
         <translation>Een kopie creëren</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="70"/>
+        <location filename="../appearancepage.cpp" line="68"/>
         <source>Rename</source>
-        <translation>Hernoemen</translation>
+        <translation>Naam wijzigen</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="72"/>
+        <location filename="../appearancepage.cpp" line="70"/>
         <source>Remove</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="122"/>
-        <location filename="../appearancepage.cpp" line="196"/>
-        <location filename="../appearancepage.cpp" line="231"/>
+        <location filename="../appearancepage.cpp" line="120"/>
+        <location filename="../appearancepage.cpp" line="194"/>
+        <location filename="../appearancepage.cpp" line="229"/>
         <source>Enter Color Scheme Name</source>
         <translation>Voer een naam in voor dit kleurenschema</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="122"/>
-        <location filename="../appearancepage.cpp" line="196"/>
-        <location filename="../appearancepage.cpp" line="231"/>
+        <location filename="../appearancepage.cpp" line="120"/>
+        <location filename="../appearancepage.cpp" line="194"/>
+        <location filename="../appearancepage.cpp" line="229"/>
         <source>File name:</source>
         <translation>Bestandsnaam:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="131"/>
-        <location filename="../appearancepage.cpp" line="207"/>
-        <location filename="../appearancepage.cpp" line="241"/>
+        <location filename="../appearancepage.cpp" line="129"/>
+        <location filename="../appearancepage.cpp" line="205"/>
+        <location filename="../appearancepage.cpp" line="239"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="131"/>
-        <location filename="../appearancepage.cpp" line="207"/>
-        <location filename="../appearancepage.cpp" line="241"/>
+        <location filename="../appearancepage.cpp" line="129"/>
+        <location filename="../appearancepage.cpp" line="205"/>
+        <location filename="../appearancepage.cpp" line="239"/>
         <source>The color scheme &quot;%1&quot; already exists</source>
         <translation>Het kleurenschema &quot;%1&quot; bestaat al</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="149"/>
-        <location filename="../appearancepage.cpp" line="172"/>
-        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="147"/>
+        <location filename="../appearancepage.cpp" line="170"/>
+        <location filename="../appearancepage.cpp" line="224"/>
         <source>Warning</source>
         <translation>Waarschuwing</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="149"/>
-        <location filename="../appearancepage.cpp" line="172"/>
-        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="147"/>
+        <location filename="../appearancepage.cpp" line="170"/>
+        <location filename="../appearancepage.cpp" line="224"/>
         <source>The color scheme &quot;%1&quot; is read only</source>
         <translation>Het kleurenschema &quot;%1&quot; is alleen-lezen</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="177"/>
+        <location filename="../appearancepage.cpp" line="175"/>
         <source>Confirm Remove</source>
         <translation>Verwijderen bevestigen</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="178"/>
+        <location filename="../appearancepage.cpp" line="176"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
-        <translation>Weet u zeker dat kleurenschema &quot;%1&quot; wilt verwijderen?</translation>
+        <translation>Weet u zeker dat u het kleurenschema &quot;%1&quot; wilt verwijderen?</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="198"/>
+        <location filename="../appearancepage.cpp" line="196"/>
         <source>%1 (copy)</source>
         <translation>%1 (kopie)</translation>
     </message>
@@ -142,7 +142,7 @@
         <location filename="../fontconfigdialog.ui" line="14"/>
         <location filename="../fontconfigdialog.cpp" line="73"/>
         <source>Font Configuration</source>
-        <translation>Lettertypeconfiguratie</translation>
+        <translation>Lettertype-instellingen</translation>
     </message>
     <message>
         <location filename="../fontconfigdialog.ui" line="29"/>
@@ -182,7 +182,7 @@
     <message>
         <location filename="../fontconfigdialog.ui" line="90"/>
         <source>Antialiasing</source>
-        <translation>Anti-aliasing</translation>
+        <translation>Anti-kartelvorming</translation>
     </message>
     <message>
         <location filename="../fontconfigdialog.ui" line="97"/>
@@ -304,7 +304,7 @@
         <location filename="../interfacepage.ui" line="138"/>
         <location filename="../interfacepage.ui" line="162"/>
         <source>Animate</source>
-        <translation>Effect</translation>
+        <translation>Uitschuiven</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="121"/>
@@ -320,7 +320,7 @@
     <message>
         <location filename="../interfacepage.ui" line="175"/>
         <source>Enable gui effects</source>
-        <translation>GUI-effecten inschakelen</translation>
+        <translation>Applicatie-effecten inschakelen</translation>
     </message>
     <message>
         <location filename="../interfacepage.ui" line="182"/>
@@ -342,6 +342,41 @@
         <source>Activate item on single-click</source>
         <translation>Item activeren met enkele klik</translation>
     </message>
+    <message>
+        <location filename="../interfacepage.ui" line="219"/>
+        <source>Toolbar button style:</source>
+        <translation>Werkbalkknop-stijl:</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.ui" line="229"/>
+        <source>Mouse wheel scroll lines:</source>
+        <translation>Aantal te scrollen regels met muis:</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="47"/>
+        <source>Only display the icon</source>
+        <translation>Alleen pictogram weergeven</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="48"/>
+        <source>Only display the text</source>
+        <translation>Alleen tekst weergeven</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="49"/>
+        <source>The text appears beside the icon</source>
+        <translation>Tekst naast het pictogram weergeven</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="50"/>
+        <source>The text appears under the icon</source>
+        <translation>Tekst onder het pictogram weergeven</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="51"/>
+        <source>Follow the application style</source>
+        <translation>Applicatiestijl volgen</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -391,7 +426,7 @@
     <message>
         <location filename="../paletteeditdialog.ui" line="79"/>
         <source>Reset palette</source>
-        <translation>Kleurenschema herstellen</translation>
+        <translation>Standaardwaarden</translation>
     </message>
     <message>
         <location filename="../paletteeditdialog.ui" line="29"/>
@@ -587,7 +622,7 @@
         <location filename="../qsspage.ui" line="76"/>
         <location filename="../qsspage.cpp" line="52"/>
         <source>Rename</source>
-        <translation>Hernoemen</translation>
+        <translation>Naam wijzigen</translation>
     </message>
     <message>
         <location filename="../qsspage.ui" line="33"/>
@@ -603,7 +638,7 @@
     <message>
         <location filename="../qsspage.cpp" line="102"/>
         <source>Enter Style Sheet Name</source>
-        <translation>Vul naam in voor stijlblad</translation>
+        <translation>Voer een naam in voor dit stijlblad</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="113"/>
@@ -625,17 +660,17 @@
     <message>
         <location filename="../qsspage.cpp" line="148"/>
         <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
-        <translation>Weet u zeker dat u stijlblad &quot;%1&quot; wilt verwijderen?</translation>
+        <translation>Weet u zeker dat u het stijlblad &quot;%1&quot; wilt verwijderen?</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="198"/>
         <source>Rename Style Sheet</source>
-        <translation>Stijlblad hernoemen</translation>
+        <translation>Stijlbladnaam wijzigen</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="198"/>
         <source>Style sheet name:</source>
-        <translation>Naam van stijlblad:</translation>
+        <translation>Stijlbladnaam:</translation>
     </message>
     <message>
         <location filename="../qsspage.cpp" line="205"/>
@@ -645,7 +680,7 @@
     <message>
         <location filename="../qsspage.cpp" line="216"/>
         <source>Unable to rename file</source>
-        <translation>Hernoemen van bestand mislukt</translation>
+        <translation>Het wijzigen van de bestandsnaam is mislukt</translation>
     </message>
 </context>
 <context>
